@@ -1,7 +1,7 @@
 package App::ListNewCPANDists;
 
 our $DATE = '2017-06-16'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -293,26 +293,29 @@ sub list_monthly_new_cpan_dists_html {
     my $cols = $res->[3]{'table.fields'};
     push @html, "<tr>\n";
     for my $col (@$cols) {
-        next if $col eq 'release';
+        next if $col eq 'release' || $col eq 'date';
         push @html, "<th>$col</th>\n";
     }
     push @html, "</tr>\n\n";
 
-    for my $row (@{ $res->[2] }) {
-        push @html, "<tr>\n";
-        for my $col (@$cols) {
-            next if $col eq 'release';
-            my $cell = HTML::Entities::encode_entities($row->{$col});
-            if ($col eq 'author') {
-                $cell = qq(<a href="https://metacpan.org/author/$cell">$cell</a>);
-            } elsif ($col eq 'dist') {
-                $cell = qq(<a href="https://metacpan.org/release/$row->{author}/$row->{release}">$cell</a>);
+    {
+        no warnings 'uninitialized';
+        for my $row (@{ $res->[2] }) {
+            push @html, "<tr>\n";
+            for my $col (@$cols) {
+                next if $col eq 'release' || $col eq 'date';
+                my $cell = HTML::Entities::encode_entities($row->{$col});
+                if ($col eq 'author') {
+                    $cell = qq(<a href="https://metacpan.org/author/$cell">$cell</a>);
+                } elsif ($col eq 'dist') {
+                    $cell = qq(<a href="https://metacpan.org/release/$row->{author}/$row->{release}">$cell</a>);
+                }
+                push @html, "<td>$cell</td>\n";
             }
-            push @html, "<td>$cell</td>\n";
+            push @html, "</tr>\n";
         }
-        push @html, "</tr>\n";
+        push @html, "</table>\n";
     }
-    push @html, "</table>\n";
 
     [200, "OK", join("", @html), {'cmdline.skip_format'=>1}];
 }
@@ -333,7 +336,7 @@ App::ListNewCPANDists - List new CPAN distributions in a given time period
 
 =head1 VERSION
 
-This document describes version 0.002 of App::ListNewCPANDists (from Perl distribution App-ListNewCPANDists), released on 2017-06-16.
+This document describes version 0.003 of App::ListNewCPANDists (from Perl distribution App-ListNewCPANDists), released on 2017-06-16.
 
 =head1 FUNCTIONS
 
